@@ -36,7 +36,7 @@ class UnknownBackendException(EmbedVideoException):
     pass
 
 
-class UnknownIdException(EmbedVideoException):
+class UnknownIdException(VideoDoesntExistException):
     """
     Exception thrown if backend is detected, but video ID cannot be parsed.
     """
@@ -206,11 +206,12 @@ class YoutubeBackend(VideoBackend):
     Backend for YouTube URLs.
     """
     re_detect = re.compile(
-        r'^(http(s)?://)?(www\.)?youtu(\.?)be(\.com)?/.*', re.I
+        r'^(http(s)?://)?(www\.|m\.)?youtu(\.?)be(\.com)?/.*', re.I
     )
 
     re_code = re.compile(
         r'''youtu(\.?)be(\.com)?/  # match youtube's domains
+            (\#/)? # for mobile urls
             (embed/)?  # match the embed url syntax
             (v/)?
             (watch\?v=)?  # match the youtube page url
@@ -230,12 +231,15 @@ class YoutubeBackend(VideoBackend):
         code = super(YoutubeBackend, self).get_code()
 
         if not code:
-            parse_data = urlparse.urlparse(self._url)
+            parsed_url = urlparse.urlparse(self._url)
+            parsed_qs = urlparse.parse_qs(parsed_url.query)
 
-            try:
-                code = urlparse.parse_qs(parse_data.query)['v'][0]
-            except KeyError:
-                raise UnknownIdException
+            if 'v' in parsed_qs:
+                code = parsed_qs['v'][0]
+            elif 'video_id' in parsed_qs:
+                code = parsed_qs['video_id'][0]
+            else:
+                raise UnknownIdException('Cannot get ID from `{0}`'.format(self._url))
 
         return code
 
@@ -288,7 +292,7 @@ class SoundCloudBackend(VideoBackend):
             'format': 'json',
             'url': self._url,
         }
-        r = requests.get(self.base_url, data=params,
+        r = requests.get(self.base_url, params=params,
                          timeout=EMBED_VIDEO_TIMEOUT)
 
         if r.status_code != 200:
